"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import mx_platform_python
from mx_platform_python.api.mx_platform_api import MxPlatformApi  # noqa: E501


class TestMxPlatformApi(unittest.TestCase):
    """MxPlatformApi unit test stubs"""

    def setUp(self):
        self.api = MxPlatformApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_aggregate_member(self):
        """Test case for aggregate_member

        Aggregate member  # noqa: E501
        """
        pass

    def test_check_balances(self):
        """Test case for check_balances

        Check balances  # noqa: E501
        """
        pass

    def test_create_category(self):
        """Test case for create_category

        Create category  # noqa: E501
        """
        pass

    def test_create_managed_account(self):
        """Test case for create_managed_account

        Create managed account  # noqa: E501
        """
        pass

    def test_create_managed_member(self):
        """Test case for create_managed_member

        Create managed member  # noqa: E501
        """
        pass

    def test_create_managed_transaction(self):
        """Test case for create_managed_transaction

        Create managed transaction  # noqa: E501
        """
        pass

    def test_create_member(self):
        """Test case for create_member

        Create member  # noqa: E501
        """
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Create tag  # noqa: E501
        """
        pass

    def test_create_tagging(self):
        """Test case for create_tagging

        Create tagging  # noqa: E501
        """
        pass

    def test_create_transaction_rule(self):
        """Test case for create_transaction_rule

        Create transaction rule  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create user  # noqa: E501
        """
        pass

    def test_delete_category(self):
        """Test case for delete_category

        Delete category  # noqa: E501
        """
        pass

    def test_delete_managed_account(self):
        """Test case for delete_managed_account

        Delete managed account  # noqa: E501
        """
        pass

    def test_delete_managed_member(self):
        """Test case for delete_managed_member

        Delete managed member  # noqa: E501
        """
        pass

    def test_delete_managed_transaction(self):
        """Test case for delete_managed_transaction

        Delete managed transaction  # noqa: E501
        """
        pass

    def test_delete_member(self):
        """Test case for delete_member

        Delete member  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Delete tag  # noqa: E501
        """
        pass

    def test_delete_tagging(self):
        """Test case for delete_tagging

        Delete tagging  # noqa: E501
        """
        pass

    def test_delete_transaction_rule(self):
        """Test case for delete_transaction_rule

        Delete transaction rule  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete user  # noqa: E501
        """
        pass

    def test_download_statement_pdf(self):
        """Test case for download_statement_pdf

        Download statement pdf  # noqa: E501
        """
        pass

    def test_enhance_transactions(self):
        """Test case for enhance_transactions

        Enhance transactions  # noqa: E501
        """
        pass

    def test_extend_history(self):
        """Test case for extend_history

        Extend history  # noqa: E501
        """
        pass

    def test_fetch_statements(self):
        """Test case for fetch_statements

        Fetch statements  # noqa: E501
        """
        pass

    def test_identify_member(self):
        """Test case for identify_member

        Identify member  # noqa: E501
        """
        pass

    def test_list_account_numbers_by_account(self):
        """Test case for list_account_numbers_by_account

        List account numbers by account  # noqa: E501
        """
        pass

    def test_list_account_numbers_by_member(self):
        """Test case for list_account_numbers_by_member

        List account numbers by member  # noqa: E501
        """
        pass

    def test_list_account_owners_by_member(self):
        """Test case for list_account_owners_by_member

        List account owners by member  # noqa: E501
        """
        pass

    def test_list_categories(self):
        """Test case for list_categories

        List categories  # noqa: E501
        """
        pass

    def test_list_default_categories(self):
        """Test case for list_default_categories

        List default categories  # noqa: E501
        """
        pass

    def test_list_default_categories_by_user(self):
        """Test case for list_default_categories_by_user

        List default categories by user  # noqa: E501
        """
        pass

    def test_list_favorite_institutions(self):
        """Test case for list_favorite_institutions

        List favorite institutions  # noqa: E501
        """
        pass

    def test_list_holdings(self):
        """Test case for list_holdings

        List holdings  # noqa: E501
        """
        pass

    def test_list_holdings_by_account(self):
        """Test case for list_holdings_by_account

        List holdings by account  # noqa: E501
        """
        pass

    def test_list_holdings_by_member(self):
        """Test case for list_holdings_by_member

        List holdings by member  # noqa: E501
        """
        pass

    def test_list_institution_credentials(self):
        """Test case for list_institution_credentials

        List institution credentials  # noqa: E501
        """
        pass

    def test_list_institutions(self):
        """Test case for list_institutions

        List institutions  # noqa: E501
        """
        pass

    def test_list_managed_accounts(self):
        """Test case for list_managed_accounts

        List managed accounts  # noqa: E501
        """
        pass

    def test_list_managed_institutions(self):
        """Test case for list_managed_institutions

        List managed institutions  # noqa: E501
        """
        pass

    def test_list_managed_members(self):
        """Test case for list_managed_members

        List managed members  # noqa: E501
        """
        pass

    def test_list_managed_transactions(self):
        """Test case for list_managed_transactions

        List managed transactions  # noqa: E501
        """
        pass

    def test_list_member_challenges(self):
        """Test case for list_member_challenges

        List member challenges  # noqa: E501
        """
        pass

    def test_list_member_credentials(self):
        """Test case for list_member_credentials

        List member credentials  # noqa: E501
        """
        pass

    def test_list_members(self):
        """Test case for list_members

        List members  # noqa: E501
        """
        pass

    def test_list_merchants(self):
        """Test case for list_merchants

        List merchants  # noqa: E501
        """
        pass

    def test_list_statements_by_member(self):
        """Test case for list_statements_by_member

        List statements by member  # noqa: E501
        """
        pass

    def test_list_taggings(self):
        """Test case for list_taggings

        List taggings  # noqa: E501
        """
        pass

    def test_list_tags(self):
        """Test case for list_tags

        List tags  # noqa: E501
        """
        pass

    def test_list_transaction_rules(self):
        """Test case for list_transaction_rules

        List transaction rules  # noqa: E501
        """
        pass

    def test_list_transactions(self):
        """Test case for list_transactions

        List transactions  # noqa: E501
        """
        pass

    def test_list_transactions_by_account(self):
        """Test case for list_transactions_by_account

        List transactions by account  # noqa: E501
        """
        pass

    def test_list_transactions_by_member(self):
        """Test case for list_transactions_by_member

        List transactions by member  # noqa: E501
        """
        pass

    def test_list_transactions_by_tag(self):
        """Test case for list_transactions_by_tag

        List transactions by tag  # noqa: E501
        """
        pass

    def test_list_user_accounts(self):
        """Test case for list_user_accounts

        List accounts  # noqa: E501
        """
        pass

    def test_list_users(self):
        """Test case for list_users

        List users  # noqa: E501
        """
        pass

    def test_read_account(self):
        """Test case for read_account

        Read account  # noqa: E501
        """
        pass

    def test_read_category(self):
        """Test case for read_category

        Read a custom category  # noqa: E501
        """
        pass

    def test_read_default_category(self):
        """Test case for read_default_category

        Read a default category  # noqa: E501
        """
        pass

    def test_read_holding(self):
        """Test case for read_holding

        Read holding  # noqa: E501
        """
        pass

    def test_read_institution(self):
        """Test case for read_institution

        Read institution  # noqa: E501
        """
        pass

    def test_read_managed_account(self):
        """Test case for read_managed_account

        Read managed account  # noqa: E501
        """
        pass

    def test_read_managed_member(self):
        """Test case for read_managed_member

        Read managed member  # noqa: E501
        """
        pass

    def test_read_managed_transaction(self):
        """Test case for read_managed_transaction

        Read managed transaction  # noqa: E501
        """
        pass

    def test_read_member(self):
        """Test case for read_member

        Read member  # noqa: E501
        """
        pass

    def test_read_member_status(self):
        """Test case for read_member_status

        Read member status  # noqa: E501
        """
        pass

    def test_read_merchant(self):
        """Test case for read_merchant

        Read merchant  # noqa: E501
        """
        pass

    def test_read_merchant_location(self):
        """Test case for read_merchant_location

        Read merchant location  # noqa: E501
        """
        pass

    def test_read_statement_by_member(self):
        """Test case for read_statement_by_member

        Read statement by member  # noqa: E501
        """
        pass

    def test_read_tag(self):
        """Test case for read_tag

        Read tag  # noqa: E501
        """
        pass

    def test_read_tagging(self):
        """Test case for read_tagging

        Read tagging  # noqa: E501
        """
        pass

    def test_read_transaction(self):
        """Test case for read_transaction

        Read transaction  # noqa: E501
        """
        pass

    def test_read_transaction_rule(self):
        """Test case for read_transaction_rule

        Read transaction rule  # noqa: E501
        """
        pass

    def test_read_user(self):
        """Test case for read_user

        Read user  # noqa: E501
        """
        pass

    def test_request_connect_widget_url(self):
        """Test case for request_connect_widget_url

        Request connect widget url  # noqa: E501
        """
        pass

    def test_request_o_auth_window_uri(self):
        """Test case for request_o_auth_window_uri

        Request oauth window uri  # noqa: E501
        """
        pass

    def test_request_widget_url(self):
        """Test case for request_widget_url

        Request widget url  # noqa: E501
        """
        pass

    def test_resume_aggregation(self):
        """Test case for resume_aggregation

        Resume aggregation  # noqa: E501
        """
        pass

    def test_update_account_by_member(self):
        """Test case for update_account_by_member

        Update account by member  # noqa: E501
        """
        pass

    def test_update_category(self):
        """Test case for update_category

        Update category  # noqa: E501
        """
        pass

    def test_update_managed_account(self):
        """Test case for update_managed_account

        Update managed account  # noqa: E501
        """
        pass

    def test_update_managed_member(self):
        """Test case for update_managed_member

        Update managed member  # noqa: E501
        """
        pass

    def test_update_managed_transaction(self):
        """Test case for update_managed_transaction

        Update managed transaction  # noqa: E501
        """
        pass

    def test_update_member(self):
        """Test case for update_member

        Update member  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Update tag  # noqa: E501
        """
        pass

    def test_update_tagging(self):
        """Test case for update_tagging

        Update tagging  # noqa: E501
        """
        pass

    def test_update_transaction(self):
        """Test case for update_transaction

        Update transaction  # noqa: E501
        """
        pass

    def test_update_transaction_rule(self):
        """Test case for update_transaction_rule

        Update transaction_rule  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Update user  # noqa: E501
        """
        pass

    def test_verify_member(self):
        """Test case for verify_member

        Verify member  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
