# flake8: noqa

"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.9.2"

# import ApiClient
from mx_platform_python.api_client import ApiClient

# import Configuration
from mx_platform_python.configuration import Configuration

# import exceptions
from mx_platform_python.exceptions import OpenApiException
from mx_platform_python.exceptions import ApiAttributeError
from mx_platform_python.exceptions import ApiTypeError
from mx_platform_python.exceptions import ApiValueError
from mx_platform_python.exceptions import ApiKeyError
from mx_platform_python.exceptions import ApiException
