"""
    MX Platform API

    The MX Platform API is a powerful, fully-featured API designed to make aggregating and enhancing financial data easy and reliable. It can seamlessly connect your app or website to tens of thousands of financial institutions.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import mx_platform_python
from mx_platform_python.model.tagging_create_request import TaggingCreateRequest


class TestTaggingCreateRequest(unittest.TestCase):
    """TaggingCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTaggingCreateRequest(self):
        """Test TaggingCreateRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TaggingCreateRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
